ControlMode

Enum ControlMode 

#[repr(u8)]
pub enum ControlMode { Constantspeed = 0, Constantpressure = 1, Proportionalpressure = 2, Constantflow = 3, Constanttemperature = 5, Automatic = 7, }

Variants



Constantspeed = 0

The pump is running at a constant speed.



Constantpressure = 1

The pump will regulate its speed to maintain a constant differential pressure over its flanges.



Proportionalpressure = 2

The pump will regulate its speed to maintain a constant differential pressure over its flanges.



Constantflow = 3

The pump will regulate its speed to maintain a constant flow through the pump.



Constanttemperature = 5

The pump will regulate its speed to maintain a constant temperature.



Automatic = 7

The operation of the pump is automatically optimized to provide the most suitable performance with respect to comfort and energy savings.

Implementations

Source

impl ControlMode

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value