#[repr(u8)]pub enum OperationMode {
Normal = 0,
Minimum = 1,
Maximum = 2,
Local = 3,
}Variants
Normal = 0
The pump is controlled by a setpoint, as defined by a connected remote sensor or by the ControlMode attribute.
Minimum = 1
This value sets the pump to run at the minimum possible speed it can without being stopped.
Maximum = 2
This value sets the pump to run at its maximum possible speed.
Local = 3
This value sets the pump to run with the local settings of the pump, regardless of what these are.
Implementations